@@ -1,3 +1,32 @@
+# This file is part of nose-perftest.
+#
+# Copyright (c) 2012, Eric Scrivner and AUTHORS
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
+#
+# * Redistributions of source code must retain the above copyright notice, this
+#   list of conditions and the following disclaimer.
+# * Redistributions in binary form must reproduce the above copyright notice,
+#   this list of conditions and the following disclaimer in the documentation
+#   and/or other materials provided with the distribution.
+# * Neither the name of the nose-perfdump nor the names of its contributors may be
+#   used to endorse or promote products derived from this software without
+#   specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
+# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+# POSSIBILITY OF SUCH DAMAGE.
+
 from functools import wraps
 import inspect
 import os
@@ -48,6 +77,10 @@ class PerfDumpPlugin(Plugin):
     def __init__(self):
         super(PerfDumpPlugin, self).__init__()
         self.database_name = 'perfdump'
+        try:
+            os.remove('{}.db'.format(self.database_name))
+        except:
+            pass
         
     def options(self, parser, env=os.environ):
         """Handle parsing additional command-line options"""
@@ -97,13 +130,13 @@ class PerfDumpPlugin(Plugin):
         self.db.commit()
 
         stream.writeln()
-        stream.writeln("Test times")
+        stream.writeln("10 slowest test times")
         self.draw_divider(stream)
         
         self.display_slowest_tests(stream)
         
         stream.writeln()
-        stream.writeln("Setup times")
+        stream.writeln("10 slowest setup times")
         self.draw_divider(stream)
         self.display_slowest_setups(stream)
 
